pub struct EntityUri { /* private fields */ }Expand description
Represents an entity URI.
Must start with the [EntityKind], followed by a colon (:) and the path to
the entity.
The path may either be just a name, which must refer to an entity in the same scope, a full path to the entity, separated by slashes, or just a UUID.
Example: my.namespace/MyEntityKind.v1:my-entity-name Example: my.namespace/MyEntityKind.v1:parent/middleman/my-entity-name Example: my.namespace/MyEntityKind.v1:parent/middleman/my-entity-name
Implementations
Sourceimpl EntityUri
impl EntityUri
pub fn as_str(&self) -> &str
pub fn into_string(self) -> String
pub fn kind(&self) -> &str
pub fn namespace(&self) -> &str
pub fn entity_type(&self) -> &str
pub fn version(&self) -> &str
pub fn name(&self) -> &str
pub fn new_kind_name( kind: &str, name: &str, ) -> Result<Self, EntityUriParseError>
pub fn parse(s: impl Into<String>) -> Result<Self, EntityUriParseError>